@@ -47,7 +47,6 @@ class LogisticTypes(str, Enum):
     SELF_PICK = "SELF_PICK"
     CUSTOM = "CUSTOM"
     OVERSEA = "OVERSEA"
-    UNKNOWN = "UNKNOWN"
 
 
 class HomeSubtypes(str, Enum):
@@ -103,8 +102,8 @@ class CartConfig(BaseCartConfig):
     receiver_address: str = ""
     receiver_tel: str = ""
     receiver_tel_ext: str = ""
-    payment_subtype: PaymentSubTypes = PaymentSubTypes.unknown
-    logistics_type: LogisticTypes = LogisticTypes.UNKNOWN
+    payment_subtype: PaymentSubTypes = PaymentSubTypes.credit
+    logistics_type: LogisticTypes = LogisticTypes.HOME
     logistics_subtype: str = ""
     logistics_cvs_store_id: Optional[str]
 
@@ -130,7 +129,6 @@ class CartConfig(BaseCartConfig):
             if values["logistics_type"] in [
                 LogisticTypes.SELF_PICK,
                 LogisticTypes.CUSTOM,
-                LogisticTypes.UNKNOWN,
             ]:
                 return ""
             elif values["logistics_type"] == LogisticTypes.HOME:
