@@ -85,6 +85,13 @@ class NewebpayCheckout:
             )
         return HTMLResponse(self.gateway.checkout_request(checkout_model))
 
+    @staticmethod
+    def _replace_item_name(name: str, count: int) -> str:
+        result = len(name) > 30 and name[:30] + "..." or name
+        if count > 1:
+            result += f"等{count}項商品"
+        return result
+
     def parse_payload(self, cart: Cart, **kwargs: Any) -> CheckoutModel:
         type_map: Dict[str, Any] = {}
         if cart.payment_subtype == PaymentSubTypes.credit:
@@ -111,10 +118,11 @@ class NewebpayCheckout:
                     type_map["CVSCOM"] = 2
                 else:
                     type_map["CVSCOM"] = 1
+        items = cart.items.items
 
         return CheckoutModel(
             Amt=cart.total,
-            ItemDesc=cart.items.items[0].name,
+            ItemDesc=self._replace_item_name(name=items[0].name, count=len(items)),
             MerchantOrderNo=auto_order_number(),
             Email=cart.buyer_email,
             NotifyURL=self.notify_url,
