@@ -95,7 +95,11 @@ class AESCryptor(BaseCryptor):
         return str_data
 
     def encrypt(self, data: Dict[str, Any]) -> str:
-        info_str = urllib.parse.urlencode(data, quote_via=urllib.parse.quote)  # type: ignore
+        parse_data = {}
+        for key, value in data.items():
+            if value is not None:
+                parse_data[key] = value
+        info_str = urllib.parse.urlencode(parse_data, quote_via=urllib.parse.quote)  # type: ignore
         cryptor = AES.new(self.hash_key.encode(), AES.MODE_CBC, self.hash_iv.encode())
         result = cryptor.encrypt(self.pad(info_str).encode())
         result = result.hex()
